==> fidpac_english.05.02.2021.zip: wp-content/themes/thinkhuge-wp/inc/current_sursharges_chart.php <==
<?
$fidpaclink = mysqli_connect("localhost", "fidelity_prod1", "prod1", "fidelity_prod1");
mysqli_select_db($fidpaclink, "fidelity_prod1");

//print_r($_SESSION);
//echo "<p>" ;
//print_r($_POST);

$database="fidelity_prod1";


if ($_POST[submit]==1){
  $selectedmonth = $_POST[months];
  $selectedyear = $_POST[years];
 } else {
  $selectedmonth = date('F');
  $selectedyear = date('Y');
}


$surchargeretrieve=mysqli_query($fidpaclink, "SELECT currentsurcharge_ID, currentsurcharge_active, currentsurcharge_month, currentsurcharge_year,
st304, st316, srs303, srs304, srs309, srs310, srs316, srs317, srs321, srs330, srs347, srs410, srs416, srs420,
srs422, srs430, srs431, srs174630, srs155, srsxm19, srs2205,
ssp301, ssp304, ssp309, ssp310, ssp316, ssp317, ssp321, ssp347,
ssp409, ssp410, ssp430, ssp440, ssp904, ssp254smo, ssp253ma, ssp2205,
ssp2304, swc308, swc309, swc310, swc312, swc316, swc317, swc347, swc904,
swcp5309, swcp73, swcp12, swc2205, swc253ma 
FROM fidelity_currentsurchargevalue WHERE currentsurcharge_month = '$selectedmonth' AND currentsurcharge_year = '$selectedyear'");


?>


	
<?

$currentsurcharge_active=0;

list($currentsurcharge_ID, $currentsurcharge_active, $currentsurcharge_month, $currentsurcharge_year,
$currentsurcharge_st304, $currentsurcharge_st316, $currentsurcharge_srs303, $currentsurcharge_srs304, $currentsurcharge_srs309, $currentsurcharge_srs310, $currentsurcharge_srs316, 
$currentsurcharge_srs317, $currentsurcharge_srs321, $currentsurcharge_srs330, $currentsurcharge_srs347, $currentsurcharge_srs410, $currentsurcharge_srs416, $currentsurcharge_srs420, 
$currentsurcharge_srs422, $currentsurcharge_srs430, $currentsurcharge_srs431, $currentsurcharge_srs174630, $currentsurcharge_srs155, $currentsurcharge_srsxm19, $currentsurcharge_srs2205,
$currentsurcharge_ssp301, $currentsurcharge_ssp304, $currentsurcharge_ssp309, $currentsurcharge_ssp310, $currentsurcharge_ssp316, $currentsurcharge_ssp317, $currentsurcharge_ssp321, $currentsurcharge_ssp347,
$currentsurcharge_ssp409, $currentsurcharge_ssp410, $currentsurcharge_ssp430, $currentsurcharge_ssp440, $currentsurcharge_ssp904, $currentsurcharge_ssp254smo, $currentsurcharge_ssp253ma, $currentsurcharge_ssp2205,
$currentsurcharge_ssp2304, $currentsurcharge_swc308, $currentsurcharge_swc309, $currentsurcharge_swc310, $currentsurcharge_swc312, $currentsurcharge_swc316, $currentsurcharge_swc317, $currentsurcharge_swc347, $currentsurcharge_swc904,
$currentsurcharge_swcp5309, $currentsurcharge_swcp7312, $currentsurcharge_swcp12, $currentsurcharge_swc2205, $currentsurcharge_swc253ma)=mysqli_fetch_row($surchargeretrieve);

if ($currentsurcharge_st304=='') {$currentsurcharge_st304='N/A';}
if ($currentsurcharge_st316=='') {$currentsurcharge_st316='N/A';}
if ($currentsurcharge_srs303=='') {$currentsurcharge_srs303='N/A';}
if ($currentsurcharge_srs304=='') {$currentsurcharge_srs304='N/A';}
if ($currentsurcharge_srs309=='') {$currentsurcharge_srs309='N/A';}
if ($currentsurcharge_srs310=='') {$currentsurcharge_srs310='N/A';}
if ($currentsurcharge_srs316=='') {$currentsurcharge_srs316='N/A';}
if ($currentsurcharge_srs317=='') {$currentsurcharge_srs317='N/A';}
if ($currentsurcharge_srs321=='') {$currentsurcharge_srs321='N/A';}
if ($currentsurcharge_srs330=='') {$currentsurcharge_srs330='N/A';}
if ($currentsurcharge_srs347=='') {$currentsurcharge_srs347='N/A';}
if ($currentsurcharge_srs410=='') {$currentsurcharge_srs410='N/A';}
if ($currentsurcharge_srs416=='') {$currentsurcharge_srs416='N/A';}
if ($currentsurcharge_srs420=='') {$currentsurcharge_srs420='N/A';}
if ($currentsurcharge_srs422=='') {$currentsurcharge_srs422='N/A';}
if ($currentsurcharge_srs430=='') {$currentsurcharge_srs430='N/A';}
if ($currentsurcharge_srs431=='') {$currentsurcharge_srs431='N/A';}
if ($currentsurcharge_srs174630=='') {$currentsurcharge_srs174630='N/A';}
if ($currentsurcharge_srs155=='') {$currentsurcharge_srs155='N/A';}
if ($currentsurcharge_srsxm19=='') {$currentsurcharge_srsxm19='N/A';}
if ($currentsurcharge_srs2205=='') {$currentsurcharge_srs2205='N/A';}
if ($currentsurcharge_ssp301=='') {$currentsurcharge_ssp301='N/A';}
if ($currentsurcharge_ssp304=='') {$currentsurcharge_ssp304='N/A';}
if ($currentsurcharge_ssp309=='') {$currentsurcharge_ssp309='N/A';}
if ($currentsurcharge_ssp310=='') {$currentsurcharge_ssp316='N/A';}
if ($currentsurcharge_ssp316=='') {$currentsurcharge_ssp316='N/A';}
if ($currentsurcharge_ssp317=='') {$currentsurcharge_ssp317='N/A';}
if ($currentsurcharge_ssp321=='') {$currentsurcharge_ssp321='N/A';}
if ($currentsurcharge_ssp347=='') {$currentsurcharge_ssp347='N/A';}
if ($currentsurcharge_ssp409=='') {$currentsurcharge_ssp409='N/A';}
if ($currentsurcharge_ssp410=='') {$currentsurcharge_ssp410='N/A';}
if ($currentsurcharge_ssp430=='') {$currentsurcharge_ssp440='N/A';}
if ($currentsurcharge_ssp904=='') {$currentsurcharge_ssp904='N/A';}
if ($currentsurcharge_ssp254smo=='') {$currentsurcharge_ssp254smo='N/A';}
if ($currentsurcharge_ssp253ma=='') {$currentsurcharge_ssp253ma='N/A';}
if ($currentsurcharge_ssp2205=='') {$currentsurcharge_ssp2205='N/A';}
if ($currentsurcharge_ssp2304=='') {$currentsurcharge_ssp2304='N/A';}
if ($currentsurcharge_swc308=='') {$currentsurcharge_swc308='N/A';}
if ($currentsurcharge_swc309=='') {$currentsurcharge_swc309='N/A';}
if ($currentsurcharge_swc310=='') {$currentsurcharge_swc310='N/A';}
if ($currentsurcharge_swc312=='') {$currentsurcharge_swc312='N/A';}
if ($currentsurcharge_swc316=='') {$currentsurcharge_swc316='N/A';}
if ($currentsurcharge_swc317=='') {$currentsurcharge_swc317='N/A';}
if ($currentsurcharge_swc347=='') {$currentsurcharge_swc347='N/A';}
if ($currentsurcharge_swc904=='') {$currentsurcharge_swc904='N/A';}
if ($currentsurcharge_swcp5309=='') {$currentsurcharge_swcp5309='N/A';}
if ($currentsurcharge_swcp7312=='') {$currentsurcharge_swcp7312='N/A';}
if ($currentsurcharge_swcp12=='') {$currentsurcharge_swcp12='N/A';}
if ($currentsurcharge_swc2205=='') {$currentsurcharge_swc2205='N/A';}
if ($currentsurcharge_swc253ma=='') {$currentsurcharge_swc253ma='N/A';}



	if (($_POST[submit]==1) AND (($_POST[months]== "") OR ($_POST[years]== ""))) {
	echo "<tr><td class='currentsurchargepopupnoinfo' colspan='2'>You have not selected<br />a month and year.<br /><br />
		  <a href='javascript:close();' class='surchargesavedlink'>Close window</a>
		  </td></tr>";

	} else {

	
	if ($currentsurcharge_active==0) {
	echo "<tr><td class='currentsurchargepopupnoinfo' colspan='2'>There is no information<br />for the month selected.<br /><br />
		  <a href='javascript:close();' class='surchargesavedlink'>Close window</a>
		  </td></tr>";

	} else {
  ?>

<h2>Surcharges for <?php echo $selectedmonth ?> <?php echo $selectedyear ?></h2>
<p class="surcharges-in-cdn">All surcharges are $CDN/LB</p>

<div class="current-surcharges-container">

 <div class="current-surcharges-column"> 
    <!-- First Table -->
      <table class="table-surcharges-fullchart">
      <tbody>

      <tr><th class="surcharges-title" colspan="2">Stainless Tube</th></tr>
      <tr><th class="surcharges-product-price">Product</th><th class="surcharges-product-price">Price</th></tr>
      <tr>
      <td class="table-product">304</td>
      <td>$ <?php echo $currentsurcharge_st304 ?></td>
      </tr>

      <tr>
      <td class="table-product">316</td>
      <td>$ <?php echo $currentsurcharge_st316 ?></td>
      </tr>
      </tbody>
      </table>
    <!-- End First Table -->
  </div>

<div class="current-surcharges-column"> 
    <!-- Second Table -->
      <table class="table-surcharges-fullchart">
      <tbody>
      <tr><th class="surcharges-title" colspan="2">Stainless Rounds, Shapes, "Mill" - Flats & Angle</th></tr>
      <tr><th class="surcharges-product-price">Product</th><th class="surcharges-product-price">Price</th></tr>
      <tr>
      <td class="table-product">303</td>
      <td>$ <?php echo $currentsurcharge_srs303; ?></td>
      </tr>
      
      <tr>
      <td class="table-product">304/L</td>
      <td>$ <?php echo $currentsurcharge_srs304; ?></td>
      </tr>
      
      <tr>
      <td class="table-product">309</td>
      <td>$ <?php echo $currentsurcharge_srs309; ?></td>
      </tr>
      
      <tr>
      <td class="table-product">310</td>
      <td>$ <?php echo $currentsurcharge_srs310; ?></td>
      </tr>

      <tr>
      <td class="table-product">316/L</td>
      <td>$ <?php echo $currentsurcharge_srs316; ?></td>
      </tr>

      <tr>
      <td class="table-product">317/L</td>
      <td>$ <?php echo $currentsurcharge_srs317; ?></td>
      </tr>

      <tr>
      <td class="table-product">321</td>
      <td>$ <?php echo $currentsurcharge_ssp321 ?></td>
      </tr>

      <tr>
      <td class="table-product">330</td>
      <td>$ <?php echo $currentsurcharge_srs330 ?></td>
      </tr>

      <tr>
      <td class="table-product">347</td>
      <td>$ <?php echo $currentsurcharge_ssp347 ?></td>
      </tr>

      <tr>
      <td class="table-product">410</td>
      <td>$ <?php echo $currentsurcharge_ssp410 ?></td>
      </tr>

      <tr>
        <td class="table-product">416</td>
        <td>$ <?php echo $currentsurcharge_srs416 ?></td>
      </tr>

      <tr>
      <td class="table-product">420</td>
      <td>$ <?php echo $currentsurcharge_srs420 ?></td>
      </tr>
        
      <tr>
      <td class="table-product">422</td>
      <td>$ <?php echo $currentsurcharge_srs422 ?></td>
      </tr>

      <tr>
      <td class="table-product">430/430F</td>
      <td>$ <?php echo $currentsurcharge_srs430 ?></td>
      </tr>

      <tr>
      <td class="table-product">431</td>
      <td>$ <?php echo $currentsurcharge_srs431 ?></td>
      </tr>

      <tr>
      <td class="table-product">17-4/630</td>
      <td>$ <?php echo $currentsurcharge_srs174630 ?></td>
      </tr>

      <tr>
      <td class="table-product">15-5</td>
      <td>$ <?php echo $currentsurcharge_srs155 ?></td>
      </tr>

      <tr>
      <td class="table-product">XM-19</td>
      <td>$ <?php echo $currentsurcharge_srsxm19 ?></td> 
      </tr>

      <tr>
      <td class="table-product">2205</td>
      <td>$ <?php echo $currentsurcharge_srs2205 ?></td>
      </tr>
      </tbody>
      </table>
<!-- End Second Table -->
</div>

<!-- Third Table -->
<div class="current-surcharges-column"> 
  <table class="table-surcharges-fullchart">
  <tbody>
  <tr><th class="surcharges-title" colspan="2">Stainless Sheet / Plate & SE Flat Bar</th></tr>
  <tr><th class="surcharges-product-price">Product</th><th class="surcharges-product-price">Price</th></tr>
  <tr>
  <td class="table-product">301</td>
  <td>$ <?php echo $currentsurcharge_ssp301 ?></td>
  </tr>

  <tr>
  <td class="table-product">304/304L</td>
  <td>$ <?php echo $currentsurcharge_ssp304 ?></td>
  </tr>

  <tr>
  <td class="table-product">309/309S</td>
  <td>$ <?php echo $currentsurcharge_ssp309 ?></td>
  </tr>

  <tr>
  <td class="table-product">310/310S</td>
  <td>$ <?php echo $currentsurcharge_ssp310 ?></td>
  </tr>

  <tr>
  <td class="table-product">316/316L</td>
  <td>$ <?php echo $currentsurcharge_ssp316 ?></td>
  </tr>

  <tr>
  <td class="table-product">317/317L</td>
  <td>$ <?php echo $currentsurcharge_ssp317 ?></td>
  </tr>

  <tr>
  <td class="table-product">321</td>
  <td>$ <?php echo $currentsurcharge_ssp321 ?></td>
  </tr>

  <tr>
  <td class="table-product">347</td>
  <td>$ <?php echo $currentsurcharge_ssp347 ?></td>
  </tr>

  <tr>
  <td class="table-product">409</td>
  <td>$ <?php echo $currentsurcharge_ssp409 ?></td>
  </tr>

  <tr>
  <td class="table-product">410</td>
  <td>$ <?php echo $currentsurcharge_ssp410 ?></td>
  </tr>

  <tr>
  <td class="table-product">430</td>
  <td>$ <?php echo $currentsurcharge_ssp430 ?></td>
  </tr>

  <tr>
  <td class="table-product">440C</td>
  <td>$ <?php echo $currentsurcharge_ssp440 ?></td>
  </tr>

  <tr>
  <td class="table-product">904L</td>
  <td>$ <?php echo $currentsurcharge_ssp904 ?></td>
  </tr>

  <tr>
  <td class="table-product">254SMO</td>
  <td>$ <?php echo $currentsurcharge_ssp254smo ?></td>
  </tr>

  <tr>
  <td class="table-product">253MA</td>
  <td>$ <?php echo $currentsurcharge_ssp253ma ?></td>
  </tr>

  <tr>
  <td class="table-product">2205</td>
  <td>$ <?php echo $currentsurcharge_ssp2205 ?></td>
  </tr>

  <tr>
  <td class="table-product">2304</td>
  <td>$ <?php echo $currentsurcharge_ssp2304 ?></td>
  </tr>
  </tbody>
  </table>
  </div>  
<!-- End Third Table -->

</div>
<!-- end container -->
<p>&nbsp;</p>
<p class="surcharges-in-cdn"><a class="full-chart-link" href="https://new.fidelitypac.ca/english/current-surcharge-rates/">(View individually)</a></p>
<?php

	} //END ELSE of if active
  } // END IF MONTH OR YEAR IS EMPTY CHECK

	?>

==> fidpac_english.07.12.2020.zip: wp-content/themes/thinkhuge-wp/inc/current_sursharges_chart.php <==
<?
$fidpaclink = mysqli_connect("localhost", "fidelity_prod1", "prod1", "fidelity_prod1");
mysqli_select_db($fidpaclink, "fidelity_prod1");

//print_r($_SESSION);
//echo "<p>" ;
//print_r($_POST);

$database="fidelity_prod1";


if ($_POST[submit]==1){
  $selectedmonth = $_POST[months];
  $selectedyear = $_POST[years];
 } else {
  $selectedmonth = date('F');
  $selectedyear = date('Y');
}


$surchargeretrieve=mysqli_query($fidpaclink, "SELECT currentsurcharge_ID, currentsurcharge_active, currentsurcharge_month, currentsurcharge_year,
st304, st316, srs303, srs304, srs309, srs310, srs316, srs317, srs321, srs330, srs347, srs410, srs416, srs420,
srs422, srs430, srs431, srs174630, srs155, srsxm19, srs2205,
ssp301, ssp304, ssp309, ssp310, ssp316, ssp317, ssp321, ssp347,
ssp409, ssp410, ssp430, ssp440, ssp904, ssp254smo, ssp253ma, ssp2205,
ssp2304, swc308, swc309, swc310, swc312, swc316, swc317, swc347, swc904,
swcp5309, swcp73, swcp12, swc2205, swc253ma 
FROM fidelity_currentsurchargevalue WHERE currentsurcharge_month = '$selectedmonth' AND currentsurcharge_year = '$selectedyear'");


?>


	
<?

$currentsurcharge_active=0;

list($currentsurcharge_ID, $currentsurcharge_active, $currentsurcharge_month, $currentsurcharge_year,
$currentsurcharge_st304, $currentsurcharge_st316, $currentsurcharge_srs303, $currentsurcharge_srs304, $currentsurcharge_srs309, $currentsurcharge_srs310, $currentsurcharge_srs316, 
$currentsurcharge_srs317, $currentsurcharge_srs321, $currentsurcharge_srs330, $currentsurcharge_srs347, $currentsurcharge_srs410, $currentsurcharge_srs416, $currentsurcharge_srs420, 
$currentsurcharge_srs422, $currentsurcharge_srs430, $currentsurcharge_srs431, $currentsurcharge_srs174630, $currentsurcharge_srs155, $currentsurcharge_srsxm19, $currentsurcharge_srs2205,
$currentsurcharge_ssp301, $currentsurcharge_ssp304, $currentsurcharge_ssp309, $currentsurcharge_ssp310, $currentsurcharge_ssp316, $currentsurcharge_ssp317, $currentsurcharge_ssp321, $currentsurcharge_ssp347,
$currentsurcharge_ssp409, $currentsurcharge_ssp410, $currentsurcharge_ssp430, $currentsurcharge_ssp440, $currentsurcharge_ssp904, $currentsurcharge_ssp254smo, $currentsurcharge_ssp253ma, $currentsurcharge_ssp2205,
$currentsurcharge_ssp2304, $currentsurcharge_swc308, $currentsurcharge_swc309, $currentsurcharge_swc310, $currentsurcharge_swc312, $currentsurcharge_swc316, $currentsurcharge_swc317, $currentsurcharge_swc347, $currentsurcharge_swc904,
$currentsurcharge_swcp5309, $currentsurcharge_swcp7312, $currentsurcharge_swcp12, $currentsurcharge_swc2205, $currentsurcharge_swc253ma)=mysqli_fetch_row($surchargeretrieve);

if ($currentsurcharge_st304=='') {$currentsurcharge_st304='N/A';}
if ($currentsurcharge_st316=='') {$currentsurcharge_st316='N/A';}
if ($currentsurcharge_srs303=='') {$currentsurcharge_srs303='N/A';}
if ($currentsurcharge_srs304=='') {$currentsurcharge_srs304='N/A';}
if ($currentsurcharge_srs309=='') {$currentsurcharge_srs309='N/A';}
if ($currentsurcharge_srs310=='') {$currentsurcharge_srs310='N/A';}
if ($currentsurcharge_srs316=='') {$currentsurcharge_srs316='N/A';}
if ($currentsurcharge_srs317=='') {$currentsurcharge_srs317='N/A';}
if ($currentsurcharge_srs321=='') {$currentsurcharge_srs321='N/A';}
if ($currentsurcharge_srs330=='') {$currentsurcharge_srs330='N/A';}
if ($currentsurcharge_srs347=='') {$currentsurcharge_srs347='N/A';}
if ($currentsurcharge_srs410=='') {$currentsurcharge_srs410='N/A';}
if ($currentsurcharge_srs416=='') {$currentsurcharge_srs416='N/A';}
if ($currentsurcharge_srs420=='') {$currentsurcharge_srs420='N/A';}
if ($currentsurcharge_srs422=='') {$currentsurcharge_srs422='N/A';}
if ($currentsurcharge_srs430=='') {$currentsurcharge_srs430='N/A';}
if ($currentsurcharge_srs431=='') {$currentsurcharge_srs431='N/A';}
if ($currentsurcharge_srs174630=='') {$currentsurcharge_srs174630='N/A';}
if ($currentsurcharge_srs155=='') {$currentsurcharge_srs155='N/A';}
if ($currentsurcharge_srsxm19=='') {$currentsurcharge_srsxm19='N/A';}
if ($currentsurcharge_srs2205=='') {$currentsurcharge_srs2205='N/A';}
if ($currentsurcharge_ssp301=='') {$currentsurcharge_ssp301='N/A';}
if ($currentsurcharge_ssp304=='') {$currentsurcharge_ssp304='N/A';}
if ($currentsurcharge_ssp309=='') {$currentsurcharge_ssp309='N/A';}
if ($currentsurcharge_ssp310=='') {$currentsurcharge_ssp316='N/A';}
if ($currentsurcharge_ssp316=='') {$currentsurcharge_ssp316='N/A';}
if ($currentsurcharge_ssp317=='') {$currentsurcharge_ssp317='N/A';}
if ($currentsurcharge_ssp321=='') {$currentsurcharge_ssp321='N/A';}
if ($currentsurcharge_ssp347=='') {$currentsurcharge_ssp347='N/A';}
if ($currentsurcharge_ssp409=='') {$currentsurcharge_ssp409='N/A';}
if ($currentsurcharge_ssp410=='') {$currentsurcharge_ssp410='N/A';}
if ($currentsurcharge_ssp430=='') {$currentsurcharge_ssp440='N/A';}
if ($currentsurcharge_ssp904=='') {$currentsurcharge_ssp904='N/A';}
if ($currentsurcharge_ssp254smo=='') {$currentsurcharge_ssp254smo='N/A';}
if ($currentsurcharge_ssp253ma=='') {$currentsurcharge_ssp253ma='N/A';}
if ($currentsurcharge_ssp2205=='') {$currentsurcharge_ssp2205='N/A';}
if ($currentsurcharge_ssp2304=='') {$currentsurcharge_ssp2304='N/A';}
if ($currentsurcharge_swc308=='') {$currentsurcharge_swc308='N/A';}
if ($currentsurcharge_swc309=='') {$currentsurcharge_swc309='N/A';}
if ($currentsurcharge_swc310=='') {$currentsurcharge_swc310='N/A';}
if ($currentsurcharge_swc312=='') {$currentsurcharge_swc312='N/A';}
if ($currentsurcharge_swc316=='') {$currentsurcharge_swc316='N/A';}
if ($currentsurcharge_swc317=='') {$currentsurcharge_swc317='N/A';}
if ($currentsurcharge_swc347=='') {$currentsurcharge_swc347='N/A';}
if ($currentsurcharge_swc904=='') {$currentsurcharge_swc904='N/A';}
if ($currentsurcharge_swcp5309=='') {$currentsurcharge_swcp5309='N/A';}
if ($currentsurcharge_swcp7312=='') {$currentsurcharge_swcp7312='N/A';}
if ($currentsurcharge_swcp12=='') {$currentsurcharge_swcp12='N/A';}
if ($currentsurcharge_swc2205=='') {$currentsurcharge_swc2205='N/A';}
if ($currentsurcharge_swc253ma=='') {$currentsurcharge_swc253ma='N/A';}



	if (($_POST[submit]==1) AND (($_POST[months]== "") OR ($_POST[years]== ""))) {
	echo "<tr><td class='currentsurchargepopupnoinfo' colspan='2'>You have not selected<br />a month and year.<br /><br />
		  <a href='javascript:close();' class='surchargesavedlink'>Close window</a>
		  </td></tr>";

	} else {

	
	if ($currentsurcharge_active==0) {
	echo "<tr><td class='currentsurchargepopupnoinfo' colspan='2'>There is no information<br />for the month selected.<br /><br />
		  <a href='javascript:close();' class='surchargesavedlink'>Close window</a>
		  </td></tr>";

	} else {
  ?>

<h2>Surcharges for <?php echo $selectedmonth ?> <?php echo $selectedyear ?></h2>
<p class="surcharges-in-cdn">All surcharges are $CDN/LB</p>


<!-- First Table -->
  <table class="table-surcharges-fullchart">
  <tbody>

  <tr><th class="surcharges-title" colspan="2">Stainless Tube</th></tr>
  <tr><th class="surcharges-product-price">Product</th><th class="surcharges-product-price">Price</th></tr>
  <tr>
  <td class="table-product">304</td>
  <td>$ <?php echo $currentsurcharge_st304 ?></td>
  </tr>

  <tr>
  <td class="table-product">316</td>
  <td>$ <?php echo $currentsurcharge_st316 ?></td>
  </tr>
<!-- End First Table -->

<!-- Second Table -->
  <tr><th class="surcharges-title" colspan="2">Stainless Rounds, Shapes, "Mill" - Flats & Angle</th></tr>
  <tr><th class="surcharges-product-price">Product</th><th class="surcharges-product-price">Price</th></tr>
  <tr>
  <td class="table-product">303</td>
  <td>$ <?php echo $currentsurcharge_srs303; ?></td>
  </tr>
  
  <tr>
  <td class="table-product">304/L</td>
  <td>$ <?php echo $currentsurcharge_srs304; ?></td>
  </tr>
  
  <tr>
  <td class="table-product">309</td>
  <td>$ <?php echo $currentsurcharge_srs309; ?></td>
  </tr>
  
  <tr>
  <td class="table-product">310</td>
  <td>$ <?php echo $currentsurcharge_srs310; ?></td>
  </tr>

  <tr>
  <td class="table-product">316/L</td>
  <td>$ <?php echo $currentsurcharge_srs316; ?></td>
  </tr>

  <tr>
  <td class="table-product">317/L</td>
  <td>$ <?php echo $currentsurcharge_srs317; ?></td>
  </tr>

  <tr>
  <td class="table-product">321</td>
  <td>$ <?php echo $currentsurcharge_ssp321 ?></td>
  </tr>

  <tr>
  <td class="table-product">330</td>
  <td>$ <?php echo $currentsurcharge_srs330 ?></td>
  </tr>

  <tr>
  <td class="table-product">347</td>
  <td>$ <?php echo $currentsurcharge_ssp347 ?></td>
  </tr>

  <tr>
  <td class="table-product">410</td>
   <td>$ <?php echo $currentsurcharge_ssp410 ?></td>
  </tr>

  <tr>
    <td class="table-product">416</td>
    <td>$ <?php echo $currentsurcharge_srs416 ?></td>
  </tr>

  <tr>
  <td class="table-product">420</td>
   <td>$ <?php echo $currentsurcharge_srs420 ?></td>
  </tr>
    
  <tr>
  <td class="table-product">422</td>
  <td>$ <?php echo $currentsurcharge_srs422 ?></td>
  </tr>

  <tr>
  <td class="table-product">430/430F</td>
  <td>$ <?php echo $currentsurcharge_srs430 ?></td>
  </tr>

  <tr>
  <td class="table-product">431</td>
  <td>$ <?php echo $currentsurcharge_srs431 ?></td>
  </tr>

  <tr>
  <td class="table-product">17-4/630</td>
  <td>$ <?php echo $currentsurcharge_srs174630 ?></td>
  </tr>

  <tr>
  <td class="table-product">15-5</td>
   <td>$ <?php echo $currentsurcharge_srs155 ?></td>
  </tr>

  <tr>
  <td class="table-product">XM-19</td>
  <td>$ <?php echo $currentsurcharge_srsxm19 ?></td> 
  </tr>

  <tr>
  <td class="table-product">2205</td>
  <td>$ <?php echo $currentsurcharge_srs2205 ?></td>
  </tr>
<!-- End Second Table -->


<!-- Third Table -->
  <tr><th class="surcharges-title" colspan="2">Stainless Sheet / Plate & SE Flat Bar</th></tr>
  <tr><th class="surcharges-product-price">Product</th><th class="surcharges-product-price">Price</th></tr>
  <tr>
  <td class="table-product">301</td>
  <td>$ <?php echo $currentsurcharge_ssp301 ?></td>
  </tr>

  <tr>
  <td class="table-product">304/304L</td>
  <td>$ <?php echo $currentsurcharge_ssp304 ?></td>
  </tr>

  <tr>
  <td class="table-product">309/309S</td>
  <td>$ <?php echo $currentsurcharge_ssp309 ?></td>
  </tr>

  <tr>
  <td class="table-product">310/310S</td>
  <td>$ <?php echo $currentsurcharge_ssp310 ?></td>
  </tr>

  <tr>
  <td class="table-product">316/316L</td>
  <td>$ <?php echo $currentsurcharge_ssp316 ?></td>
  </tr>

  <tr>
  <td class="table-product">317/317L</td>
  <td>$ <?php echo $currentsurcharge_ssp317 ?></td>
  </tr>

  <tr>
  <td class="table-product">321</td>
  <td>$ <?php echo $currentsurcharge_ssp321 ?></td>
  </tr>

  <tr>
  <td class="table-product">347</td>
  <td>$ <?php echo $currentsurcharge_ssp347 ?></td>
  </tr>

  <tr>
  <td class="table-product">409</td>
  <td>$ <?php echo $currentsurcharge_ssp409 ?></td>
  </tr>

  <tr>
  <td class="table-product">410</td>
  <td>$ <?php echo $currentsurcharge_ssp410 ?></td>
  </tr>

  <tr>
  <td class="table-product">430</td>
  <td>$ <?php echo $currentsurcharge_ssp430 ?></td>
  </tr>

  <tr>
  <td class="table-product">440C</td>
  <td>$ <?php echo $currentsurcharge_ssp440 ?></td>
  </tr>

  <tr>
  <td class="table-product">904L</td>
  <td>$ <?php echo $currentsurcharge_ssp904 ?></td>
  </tr>

  <tr>
  <td class="table-product">254SMO</td>
  <td>$ <?php echo $currentsurcharge_ssp254smo ?></td>
  </tr>

  <tr>
  <td class="table-product">253MA</td>
  <td>$ <?php echo $currentsurcharge_ssp253ma ?></td>
  </tr>

  <tr>
  <td class="table-product">2205</td>
  <td>$ <?php echo $currentsurcharge_ssp2205 ?></td>
  </tr>

  <tr>
  <td class="table-product">2304</td>
  <td>$ <?php echo $currentsurcharge_ssp2304 ?></td>
  </tr>

<!-- End Third Table -->


<!-- Forth Table -->
  <tr><th class="surcharges-title" colspan="2">Stainless Welding Consumables</th></tr>
  <tr><th class="surcharges-product-price">Product</th><th class="surcharges-product-price">Price</th></tr>
  <tr>
  <td class="table-product">308 / 308H / 308L / 308LSi</td>
  <td>$ <?php echo $currentsurcharge_swc308 ?></td>
  </tr>

  <tr>
  <td class="table-product">309 / 309 / 309L / 309LSi</td>
  <td>$ <?php echo $currentsurcharge_swc309 ?></td> 
  </tr>

  <tr>
  <td class="table-product">310</td>
  <td>$ <?php echo $currentsurcharge_swc310 ?></td>
  </tr>

  <tr>
  <td class="table-product">312</td>
  <td>$ <?php echo $currentsurcharge_swc312 ?></td>
  </tr>

  <tr>
  <td class="table-product">316 / 316H / 316L / 316LSi</td>
  <td>$ <?php echo $currentsurcharge_swc316 ?></td>
  </tr>

  <tr>
  <td class="table-product">317L</td>
  <td>$ <?php echo $currentsurcharge_swc317 ?></td>
  </tr>

  <tr>
  <td class="table-product">347</td>
  <td>$ <?php echo $currentsurcharge_swc347 ?></td>
  </tr>

  <tr>
  <td class="table-product">904L</td>
  <td>$ <?php echo $currentsurcharge_swc904 ?></td>
  </tr>

  <tr>
  <td class="table-product">P5 (309MOL)</td>
  <td>$ <?php echo $currentsurcharge_swcp5309 ?></td>
  </tr>

  <tr>
  <td class="table-product">P7 (312)</td>
  <td>$ <?php echo $currentsurcharge_swcp7312 ?></td>
  </tr>

  <tr>
  <td class="table-product">P12C / P12R</td>
  <td>$ <?php echo $currentsurcharge_swcp12 ?></td>
  </tr>

  <tr>
  <td class="table-product">253MA</td>
  <td>$ <?php echo $currentsurcharge_swc253ma ?></td>
  </tr>

  <tr>
  <td class="table-product">2205 / 2209 / 2507 / P100</td>
  <td>$ <?php echo $currentsurcharge_swc2205 ?></td>
  </tr>

  </tbody>

  </table>
<!-- End Forth Table -->
<p>&nbsp;</p>
<p class="surcharges-in-cdn"><a class="full-chart-link" href="https://new.fidelitypac.ca/english/current-surcharge-rates/">(View individually)</a></p>
<?php

	} //END ELSE of if active
  } // END IF MONTH OR YEAR IS EMPTY CHECK

	?>
